@@ -285,12 +285,10 @@ void MBIRReconstruct(
         #endif
     }
 
-    // Limit threads for smaller problem size if no positivity constraint
+    // Limit threads for smaller problem size
     int max_threads = omp_get_max_threads();
-    if(reconparams.Positivity==0) {
-        i = ((Nx < Ny) ? Nx : Ny) / (2*SVLength+1) * SV_per_Z;
-        max_threads = ( i < max_threads) ? i : max_threads ;
-    }
+    i = ((Nx < Ny) ? Nx : Ny) / (2*SVLength+1) * SV_per_Z;
+    max_threads = ( i < max_threads) ? i : max_threads;
 
     #pragma omp parallel num_threads(max_threads)
     {
@@ -788,7 +786,7 @@ void super_voxel_recon(
                 exit(-1);
             }
 
-            pixel = tempV[currentSlice] + step;  /* can apply over-relaxation to the step size here */
+            pixel = tempV[currentSlice] + (reconparams.RelaxFactor)*step;
 
             if(PositivityFlag)
                 image[(size_t)(startSlice+currentSlice)*Nxy + j_new*Nx+k_new] = ((pixel < 0.0) ? 0.0 : pixel);
@@ -892,7 +890,7 @@ void super_voxel_recon(
     free((void *)bandWidth);
     free((void *)bandWidthTemp);
 
-    headNodeArray[jj_new].x=totalChange_loc;
+    headNodeArray[jj_new].x=totalChange_loc/SV_depth_modified;
     *NumUpdates += NumUpdates_loc;
     *totalValue += totalValue_loc;
     *totalChange += totalChange_loc;
